import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)

/**
 * An ant that collects food.
 * 
 * @author Michael Kolling
 * @version 1.1
 */
public class Ant extends Creature
{
    private boolean carryingFood;
    
    /**
     * Create an ant with a given home hill. The initial speed is zero (not moving).
     */
    public Ant(AntHill home)
    {
        setHomeHill(home);
        carryingFood = false;
    }

    /**
     * Do what an ant's gotta do.
     */
    public void act()
    {
        if(carryingFood) {
            walkTowardsHome();
            checkForHome();
        }
        else {
            randomWalk();
        }
        checkForFood();
    }

    private void checkForHome() {
        AntHill hill = (AntHill)getOneIntersectingObject(AntHill.class);
        if(hill != null) {
            setImage("ant.gif");
            carryingFood = false;
            hill.countFood();
        }
    }
    
    /**
     * Checks to see if the ant has stumbled upon some food.
     */
    private void checkForFood() {
        if(getOneIntersectingObject(Food.class) != null) {
            //Greenfoot.stop();
            setImage("ant-with-food.gif");
            carryingFood = true;
        }
    }
    
    /**
     * Are we home?
     */
    private boolean atHome()
    {
        if (getHomeHill() != null) {
            return (Math.abs(getX() - getHomeHill().getX()) < 4) && (Math.abs(getY() - getHomeHill().getY()) < 4);
        }
        else {
            return false;
        }
        
    }
}